summaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
authorpkanwar <pkanwar@google.com>2017-05-21 10:24:30 -0700
committerpkanwar <pkanwar@google.com>2017-06-12 13:54:32 -0700
commitb10761ea89d38a705b3ffb539e9550777b2b5d56 (patch)
treed1a00a61c8d10083bdaf5259407db704645476ed /include
parentc2a8f44f115ae7d72cd866daedd1530e03b5808f (diff)
downloadandroid_hardware_ril-b10761ea89d38a705b3ffb539e9550777b2b5d56.tar.gz
android_hardware_ril-b10761ea89d38a705b3ffb539e9550777b2b5d56.tar.bz2
android_hardware_ril-b10761ea89d38a705b3ffb539e9550777b2b5d56.zip
Radio Interface changes to allow the modem to query the framework
for the key. We will now pass the ImsiEncryptionInfo object which includes mnc/mcc. BUG: 35606429 Test: manual Change-Id: I670465878e01e382b074a6434fbaf1bcb0fecc65
Diffstat (limited to 'include')
-rw-r--r--include/telephony/ril.h18
1 files changed, 11 insertions, 7 deletions
diff --git a/include/telephony/ril.h b/include/telephony/ril.h
index 23d06d0..4f11788 100644
--- a/include/telephony/ril.h
+++ b/include/telephony/ril.h
@@ -741,13 +741,17 @@ typedef struct {
} RIL_CarrierRestrictions;
typedef struct {
- const uint8_t * carrierKey; /* Public Key from the Carrier used to encrypt the
- * IMSI/IMPI.
- */
- const char * KeyIdentifier; /* The keyIdentifier Attribute value pair that helps
- * a server locate the private key to decrypt the
- * permanent identity.
- */
+ char * mcc; /* MCC of the Carrier. */
+ char * mnc ; /* MNC of the Carrier. */
+ uint8_t * carrierKey; /* Public Key from the Carrier used to encrypt the
+ * IMSI/IMPI.
+ */
+ char * keyIdentifier; /* The keyIdentifier Attribute value pair that helps
+ * a server locate the private key to decrypt the
+ * permanent identity.
+ */
+ int64_t expirationTime; /* Date-Time (in UTC) when the key will expire. */
+
} RIL_CarrierInfoForImsiEncryption;
/* See RIL_REQUEST_LAST_CALL_FAIL_CAUSE */